﻿using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using System.Xml.Linq;
using System.Linq;
using System.Collections.Generic;
using SP = Microsoft.SharePoint.WebPartPages;
using System.Web.UI.HtmlControls;
using System.Net;
using System.Xml;


namespace WebPartsInAction.Ch10.DynRSSWebPart.DynamicRSSWebPart {
    [ToolboxItemAttribute(false)]
    public class DynamicRSSWebPart : WebPart, IWebPartPageComponentProvider {
        public DynamicRSSWebPart() {
        }

        private HtmlInputHidden hiddenInput;
        protected UpdatePanel updatePanel;
        protected Button refreshButton;

        protected override void OnLoad(EventArgs e) {
            if (this.hiddenInput != null &&
                !string.IsNullOrEmpty(this.hiddenInput.Value) &&
                (this.Page.IsPostBack || this.Page.IsCallback)) {

                if (hiddenInput.Value != this.RssFeedUrl) {
                    if (this.WebPartManager != null) {
                        this.SetPersonalizationDirty();
                        SP.SPWebPartManager wpMgr = this.WebPartManager as SP.SPWebPartManager;
                        if (wpMgr != null) {
                            this.RssFeedUrl = hiddenInput.Value;
                            wpMgr.SaveChanges(wpMgr.GetStorageKey(this));
                        }
                    }
                }
            }
            base.OnLoad(e);
        }

        protected override void CreateChildControls() {
            hiddenInput = new HtmlInputHidden() {
                ID = "HiddenFeedControl",
                Value = this.RssFeedUrl
            };

            this.Controls.Add(hiddenInput);
            ScriptLink.Register(this.Page, "jquery-1.4.2.min.js", false);
            ScriptLink.Register(this.Page, "DynRSSWebPart.js", false);

            ScriptLink.RegisterScriptAfterUI(this.Page, "CUI.js", false, true);
            ScriptLink.RegisterScriptAfterUI(this.Page, "SP.Ribbon.js", false, true);
            ScriptLink.RegisterScriptAfterUI(this.Page, "RssRibbon.js", false);

            // Visible for all pages that this WP is present
            SPRibbon current = SPRibbon.GetCurrent(this.Page);
            if (current != null) {
                current.CommandUIVisible = true;
                current.MakeTabAvailable("WebPartsInAction.RssTab");

            }
            this.CssClass = "feedWebPart";

            updatePanel = new UpdatePanel();
            updatePanel.ID = "updatePanel";
            updatePanel.UpdateMode = UpdatePanelUpdateMode.Conditional;

            this.Controls.Add(updatePanel);

            if (string.IsNullOrEmpty(this.RssFeedUrl)) {
                HyperLink hl = new HyperLink {
                    NavigateUrl = string.Format("javascript:ShowToolPane2Wrapper('Edit','129','{0}');", this.ID),
                    ID = string.Format("MsoFrameworkToolpartDefmsg_{0}", this.ID),
                    Text = "Click here to configure the Web Part..."
                };
                this.Controls.Add(hl);
                return;
            }

            refreshButton = new Button() {
                Text = "Refresh",
                ID = "refreshButton",
                CssClass = "ms-NarrowButtonHeightWidth"
            };
            this.Controls.Add(refreshButton);

            updatePanel.Triggers.Add(new AsyncPostBackTrigger() {
                ControlID = refreshButton.ID
            });


            this.ChildControlsCreated = true;
        }
        protected override void Render(HtmlTextWriter writer) {

            base.Render(writer);
        }
        protected override void OnPreRender(EventArgs e) {
            ScriptManager.RegisterStartupScript(this.Page,
                typeof(DynamicRSSWebPart),
                "RssWebPartPageComponent" + this.ClientID,
                string.Format("SP.SOD.executeOrDelayUntilScriptLoaded(" +
                    "function(){{createRssRibbon('{0}').register();}}," +
                    "'rssribbon.js');",
                    SPRibbon.GetWebPartPageComponentId(this)),
                true);

            if (!string.IsNullOrEmpty(this.RssFeedUrl)) {
                XElement feed = null;
                try {
                    feed = XElement.Load(this.RssFeedUrl);
                }
                catch (Exception) {
                    ScriptManager.RegisterClientScriptBlock(updatePanel, typeof(DynamicRSSWebPart), "FeedNotFound" + this.ClientID, string.Format("ExecuteOrDelayUntilScriptLoaded(function() {{feeds.feedNotFound('{0}')}}, 'sp.js');", this.RssFeedUrl), true);
                }
                if (feed != null) {
                    BulletedList bulletedList = new BulletedList();
                    bulletedList.DisplayMode = BulletedListDisplayMode.HyperLink;

                    var items = feed.Descendants("item").Take(this.ItemCount);

                    foreach (var item in items) {
                        bulletedList.Items.Add(new ListItem() {
                            Text = item.Descendants("title").First().Value,
                            Value = item.Descendants("link").First().Value
                        });
                    }
                    updatePanel.ContentTemplateContainer.Controls.Add(bulletedList);
                }

                updatePanel.ContentTemplateContainer.Controls.Add(new LiteralControl("Last updated "));
                updatePanel.ContentTemplateContainer.Controls.Add(new LiteralControl(DateTime.Now.ToString()));

                if (this.AutoRefresh) {
                    ScriptLink.Register(this.Page, "jquery.timers-1.2.js", false);
                    this.Page.ClientScript.RegisterClientScriptBlock(typeof(DynamicRSSWebPart), "AutoRefresh", String.Format("feeds.feedTimer('{0}');", this.ClientID), true);
                }
            }
            base.OnPreRender(e);
        }

        public override WebPartVerbCollection Verbs {
            get {
                List<WebPartVerb> verbs = new List<WebPartVerb>();

                WebPartVerb editVerb = new WebPartVerb("Client_Click",
                    string.Format("feeds.editFeed('{0}')", this.ClientID)) {
                        Text = "Edit feed..."
                    };
                verbs.Add(editVerb);

                return new WebPartVerbCollection(verbs);
            }
        }

        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("RSS feed Url")]
        [WebDescription("Enter the Url to the RSS feed")]
        [SP.RequiresDesignerPermission(true)]
        public string RssFeedUrl {
            get;
            set;
        }
        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("Items to show")]
        [WebDescription("The number of RSS feed items to show")]
        public int ItemCount {
            get;
            set;
        }

        [WebBrowsable]
        [WebDisplayName("Auto refresh")]
        [Personalizable(PersonalizationScope.Shared)]
        public bool AutoRefresh {
            get;
            set;
        }




        public WebPartContextualInfo WebPartContextualInfo {
            get {
                WebPartContextualInfo contextInfo = new WebPartContextualInfo();
                contextInfo.ContextualGroups.Add(new WebPartRibbonContextualGroup() {
                    Id = "WebPartsInAction.ContextualTabGroup",
                    VisibilityContext = "WebPartsInAction.CustomVisibilityContext",
                    Command = "RssWebPart.ContextualGroupCommand"
                });
                contextInfo.Tabs.Add(new WebPartRibbonTab() {
                    Id = "WebPartsInAction.RssContextualTab",
                    VisibilityContext = "WebPartsInAction.CustomVisibilityContext"
                });
                contextInfo.PageComponentId = SPRibbon.GetWebPartPageComponentId(this);
                return contextInfo;
            }
        }
    }
}
