using System;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Security;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.WebPartPages;

namespace WebPartsInAction.Ch12.Mobility.Features.TaskCountMobileAdapterFeature {
    /// <summary>
    /// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
    /// </summary>
    /// <remarks>
    /// The GUID attached to this class may be used during packaging and should not be modified.
    /// </remarks>

    [Guid("09d5956f-9fa9-4124-a4ec-c6a8ba1c351e")]
    public class TaskCountMobileAdapterFeatureEventReceiver : SPFeatureReceiver {
        // Uncomment the method below to handle the event raised after a feature has been activated.

        public const string jobName = "browser-definition-timer-job";


        public override void FeatureActivated(SPFeatureReceiverProperties properties) {
            SPWebApplication webApplication = properties.Feature.Parent as SPWebApplication;

            BrowserDefinitionTimerJob newJob = new BrowserDefinitionTimerJob(jobName, webApplication) {
                Schedule = new SPOneTimeSchedule(DateTime.Now)
            };
            newJob.Properties.Add("add", true);
            newJob.Update();

            string assembly = this.GetType().Assembly.FullName;
            string ns = "WebPartsInAction.Ch12.Mobility";
            SPWebConfigModification safeControlMod = new SPWebConfigModification {
                Path = "configuration/SharePoint/SafeControls",
                Name = String.Format("SafeControl[@Assembly='{0}'][@Namespace='{1}'][@TypeName='*'][@Safe='True']", assembly, ns),
                Sequence = 0,
                Owner = this.GetType().FullName,
                Type = SPWebConfigModification.SPWebConfigModificationType.EnsureChildNode,
                Value = String.Format("<SafeControl Assembly='{0}' Namespace='{1}' TypeName='*' Safe='True' />", assembly, ns)
            };
            webApplication.WebConfigModifications.Add(safeControlMod);


            webApplication.Update();
            webApplication.Farm.Services.GetValue<SPWebService>().ApplyWebConfigModifications();

        }


        // Uncomment the method below to handle the event raised before a feature is deactivated.

        public override void FeatureDeactivating(SPFeatureReceiverProperties properties) {
            SPWebApplication webApplication = properties.Feature.Parent as SPWebApplication;

            BrowserDefinitionTimerJob newJob = new BrowserDefinitionTimerJob(jobName, webApplication) {
                Schedule = new SPOneTimeSchedule(DateTime.Now)
            };
            newJob.Properties.Add("add", false);
            newJob.Update();


            for (int i = webApplication.WebConfigModifications.Count - 1; i >= 0; i--) {
                SPWebConfigModification mod = webApplication.WebConfigModifications[i];
                if (mod.Owner == this.GetType().FullName) {
                    webApplication.WebConfigModifications.Remove(mod);
                }
            }

            webApplication.Update();
            webApplication.Farm.Services.GetValue<SPWebService>().ApplyWebConfigModifications();
            



        }


        // Uncomment the method below to handle the event raised after a feature has been installed.

        //public override void FeatureInstalled(SPFeatureReceiverProperties properties)
        //{
        //}


        // Uncomment the method below to handle the event raised before a feature is uninstalled.

        //public override void FeatureUninstalling(SPFeatureReceiverProperties properties)
        //{
        //}

        // Uncomment the method below to handle the event raised when a feature is upgrading.

        //public override void FeatureUpgrading(SPFeatureReceiverProperties properties, string upgradeActionName, System.Collections.Generic.IDictionary<string, string> parameters)
        //{
        //}
    }
}
