﻿using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using System.Linq;
using System.Xml.Linq;
using System.Collections.Generic;
using WebPartsInAction.Ch14.Connections.FeedInputWebPart;
using System.Data;
using System.Collections.Specialized;
using System.Collections;

namespace WebPartsInAction.Ch14.Connections.RssWebPart {
    [ToolboxItemAttribute(false)]
    public class RssWebPart : WebPart {
        public RssWebPart() {
            this.ItemCount = 5;
        }

        private void getRowData(object rowData) {
            DataRowView dataRow = rowData as DataRowView;
            if (dataRow != null) {
                foreach (PropertyDescriptor property in this._row.Schema) {
                    if (property.Name == "URL") {
                        SPFieldUrlValue value = new SPFieldUrlValue(dataRow[property.Name].ToString());
                        this.RssFeedUrl = value.Url;
                        return;
                    }
                }
            }
            this.RssFeedUrl = null;
        }
        private void getParametersData(object rowData) {
            IDictionary dictionary = rowData as IDictionary;
            if (dictionary != null) {
                SPFieldUrlValue value = new SPFieldUrlValue(dictionary["RssUrl"].ToString());
                this.RssFeedUrl = value.Url;
                return;
            }
            this.RssFeedUrl = null;
        }

        protected UpdatePanel updatePanel;

        protected override void CreateChildControls() {
            updatePanel = new UpdatePanel();
            this.Controls.Add(updatePanel);
            base.CreateChildControls();
        }


        protected override void OnPreRender(EventArgs e) {
            if (IsConnected()) {
                if (this._provider != null) {
                    ScriptManager scriptManager = ScriptManager.GetCurrent(this.Page);
                    if (scriptManager != null && _provider.AsyncTrigger != null) {
                        scriptManager.RegisterAsyncPostBackControl(_provider.AsyncTrigger);
                    }
                    this.RssFeedUrl = this._provider.Url;
                }
                else if (this._row != null) {
                    this._row.GetRowData(getRowData);
                }
                else {
                    this._parameters.GetParametersData(getParametersData);
                }
            }
            renderFeed();
            
            base.OnPreRender(e);
        }
        protected override void RenderContents(HtmlTextWriter writer) {
            
            base.RenderContents(writer);
        }

        private void renderFeed() {
            if (string.IsNullOrEmpty(this.RssFeedUrl)) {
                return;
            }

            XElement feed = XElement.Load(this.RssFeedUrl);

            var items = feed.Descendants("item").Take(this.ItemCount);

            BulletedList bulletedList = new BulletedList();
            bulletedList.DisplayMode = BulletedListDisplayMode.HyperLink;

            foreach (var item in items) {
                
                bulletedList.Items.Add(new ListItem(
                    item.Descendants("title").First().Value,
                    item.Descendants("link").First().Value));

                
            }
            updatePanel.ContentTemplateContainer.Controls.Add(bulletedList);
        }


        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("RSS feed Url")]
        [WebDescription("Enter the Url to the RSS feed")]
        public string RssFeedUrl {
            get;
            set;
        }
        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("Items to show")]
        [WebDescription("The number of RSS feed items to show")]
        public int ItemCount {
            get;
            set;
        }



        IUrlConnection _provider;

        [ConnectionConsumer("Feed Url", "feed")]
        public void GetFeedConnection(IUrlConnection provider) {
            _provider = provider;
           
        }

        internal bool IsConnected() {
            return _provider != null || _row != null || _parameters != null;
        }
        IWebPartRow _row;
        [ConnectionConsumer("Row", "row")]
        public void GetRowData(IWebPartRow row) {
            _row = row;
        }
        IWebPartParameters _parameters;
        [ConnectionConsumer("Parameters", "parameters")]
        public void GetRowParameters(IWebPartParameters parameters) {

            PropertyDescriptorCollection pdc = new PropertyDescriptorCollection(new PropertyDescriptor[]{
                TypeDescriptor.CreateProperty(this.GetType(), "RssUrl", typeof(string))
            });
            parameters.SetConsumerSchema(pdc);
            _parameters = parameters;
        }


    }

}
