﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Globalization;

namespace WebPartsInAction.Ch5.CoordinateWebPart {
    class CoordinateConverter : ExpandableObjectConverter {
        public override bool CanConvertTo(ITypeDescriptorContext context,
                            System.Type destinationType) {
            if (destinationType == typeof(Coordinate))
                return true;
            return base.CanConvertTo(context, destinationType);
        }
        public override object ConvertTo(ITypeDescriptorContext context,
                               CultureInfo culture, object value,
                              System.Type destinationType) {
            if (destinationType == typeof(System.String) &&
                value is Coordinate) {
                Coordinate coord = (Coordinate)value;
                return coord.ToString();
            }
            return base.ConvertTo(context, culture, value, destinationType);
        }

        public override bool CanConvertFrom(ITypeDescriptorContext context,
                             System.Type sourceType) {
            if (sourceType == typeof(string))
                return true;
            return base.CanConvertFrom(context, sourceType);
        }
        public override object ConvertFrom(ITypeDescriptorContext context,
                               CultureInfo culture, object value) {
            if (value is string) {
                try {
                    string s = (string)value;
                    string[] arr = s.Split(':');
                    Coordinate coord = new Coordinate();
                    coord.Latitude = float.Parse(arr[0],
                                    CultureInfo.CurrentCulture);
                    coord.Longitude = float.Parse(arr[1],
                                      CultureInfo.CurrentCulture);
                    return coord;
                }
                catch {
                    throw new ArgumentException("Can not convert '" +
                              (string)value + "' to type a Coordinate");
                }
            }
            return base.ConvertFrom(context, culture, value);
        }
    }
}
