﻿using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using System.Xml.Linq;
using System.Collections.Generic;
using System.Linq;

namespace WebPartsInAction.Ch5.RSSWebPart.RssWebPart {
    [ToolboxItemAttribute(false)]
    public class RssWebPart : WebPart, IWebEditable {
        public RssWebPart() {
        }

        protected override void CreateChildControls() {
            if (String.IsNullOrEmpty(this.RssFeedUrl)) {
                HyperLink hl = new HyperLink();
                hl.NavigateUrl = String.Format(
                    "javascript:ShowToolPane2Wrapper('Edit','129','{0}');",
                    this.ID);
                hl.ID = String.Format("MsoFrameworkToolpartDefmsg_{0}", this.ID);
                hl.Text = "Click here to configure the Web Part";
                this.Controls.Add(hl);
                return;
            }

            XElement feed = XElement.Load(this.RssFeedUrl);

            BulletedList bulletedList = new BulletedList();
            this.Controls.Add(bulletedList);
            bulletedList.DisplayMode = BulletedListDisplayMode.HyperLink;

            var items = feed.Descendants("item").Take(this.ItemCount);

            foreach (var item in items) {
                bulletedList.Items.Add(new ListItem() {
                    Text = item.Descendants("title").First().Value,
                    Value = item.Descendants("link").First().Value
                });
            }
            this.ChildControlsCreated = true;
        }

        [WebBrowsable(false)]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("RSS feed Url")]
        [WebDescription("Enter the Url to the RSS feed")]
        public string RssFeedUrl {
            get;
            set;
        }
        [WebBrowsable(false)]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("Items to show")]
        [WebDescription("The number of RSS feed items to show")]
        public int ItemCount {
            get;
            set;
        }

        [Personalizable(PersonalizationScope.Shared)]
        public bool CacheData {
            get;
            set;
        }
        [Personalizable(PersonalizationScope.Shared)]
        public int CacheTime {
            get;
            set;
        }


        EditorPartCollection IWebEditable.CreateEditorParts() {
            List<EditorPart> editors = new List<EditorPart>();
            RssWebPartEditorPart editorPart =
                new RssWebPartEditorPart();
            editorPart.ID = this.ID + "_editorPart";
            editors.Add(editorPart);
            return new EditorPartCollection(editors);
        }

        object IWebEditable.WebBrowsableObject {
            get { return this; }
        }

    }

}
