﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint.Utilities;
using System.Globalization;

namespace WebPartsInAction.Ch6.Localization {
    [AttributeUsage(AttributeTargets.Property, AllowMultiple = false, Inherited = true)]
    public class LocalizedWebDescriptionAttribute : WebDescriptionAttribute {

        private bool m_isLocalized;

        public LocalizedWebDescriptionAttribute() {
        }

        public LocalizedWebDescriptionAttribute(string description)
            : this(description, "core") {
        }
        public LocalizedWebDescriptionAttribute(string description, string resourceFile)
            : base(description) {
            this.ResourceFile = resourceFile;
        }

        public string ResourceFile {
            get;
            set;
        }

        public override string Description {
            get {
                if (!m_isLocalized) {
                    this.DescriptionValue = SPUtility.GetLocalizedString("$Resources:" + base.Description, this.ResourceFile, (uint)CultureInfo.CurrentUICulture.LCID);
                    m_isLocalized = true;
                }
                return base.Description;
            }
        }
    }
}
