﻿using System;
using System.ComponentModel;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using System.Xml.Linq;
using System.Linq;
using System.Collections.Generic;

namespace WebPartsInAction.Ch9.AsyncRSSWebPart.AsyncRSSFeedWebPart {
    [ToolboxItemAttribute(false)]
    public class AsyncRSSFeedWebPart  : WebPart, IWebEditable {
        public AsyncRSSFeedWebPart() {
        }
     
        private RSSFeedAsyncTask _asyncTask;
        BulletedList _feedItems;

        protected override void CreateChildControls() {
            if (string.IsNullOrEmpty(this.RssFeedUrl)) {
                HyperLink hl = new HyperLink();
                hl.NavigateUrl = string.Format(
                    "javascript:ShowToolPane2Wrapper('Edit','129','{0}');",
                    this.ID);
                hl.ID = string.Format("MsoFrameworkToolpartDefmsg_{0}", this.ID);
                hl.Text = "Click here to configure the Web Part";
                this.Controls.Add(hl);
                return;
            }
            _asyncTask = new RSSFeedAsyncTask(this.RssFeedUrl, feedFetched);
            PageAsyncTask pageAsyncTask = new PageAsyncTask(_asyncTask.OnBegin, _asyncTask.OnEnd, _asyncTask.OnTimeout, "RSSFeedAsyncTask", true);
            Page.RegisterAsyncTask(pageAsyncTask);

            _feedItems = new BulletedList();
            _feedItems.DisplayMode = BulletedListDisplayMode.HyperLink;

            this.Controls.Add(_feedItems);
            this.ChildControlsCreated = true;
        }

        private void feedFetched() {
            if(_asyncTask != null && _asyncTask.FeedData != null) {
                XElement feed = _asyncTask.FeedData;

                var items = feed.Descendants("item").Take(this.ItemCount);

                foreach (var item in items) {
                    _feedItems.Items.Add(new ListItem() {
                        Text = item.Descendants("title").First().Value,
                        Value = item.Descendants("link").First().Value
                    });
                }
            }
        }

        protected override void OnPreRender(EventArgs e) {
            base.OnPreRender(e);
        }

        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("RSS feed Url")]
        [WebDescription("Enter the Url to the RSS feed")]
        public string RssFeedUrl {
            get;
            set;
        }
        [WebBrowsable]
        [Personalizable(PersonalizationScope.Shared)]
        [WebDisplayName("Items to show")]
        [WebDescription("The number of RSS feed items to show")]
        public int ItemCount {
            get;
            set;
        }

        [Personalizable(PersonalizationScope.Shared)]
        public bool CacheData {
            get;
            set;
        }
        [Personalizable(PersonalizationScope.Shared)]
        public int CacheTime {
            get;
            set;
        }


        EditorPartCollection IWebEditable.CreateEditorParts() {
            List<EditorPart> editors = new List<EditorPart>();
            AsyncRSSFeedWebPartEditorPart editorPart =
                new AsyncRSSFeedWebPartEditorPart();
            editorPart.ID = this.ID + "_editorPart";
            editors.Add(editorPart);
            return new EditorPartCollection(editors);
        }

        object IWebEditable.WebBrowsableObject {
            get { return this; }
        }

    }
}
