﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint.WebPartPages;
using System.Web.UI;

namespace WebPartsInAction.Ch9.AsyncRSSWebPart.AsyncRSSFeedWebPart {
    class AsyncRSSFeedWebPartEditorPart : EditorPart {

        protected TextBox m_feedUrl;
        protected TextBox m_itemCount;


        protected CheckBox m_cache;
        protected TextBox m_cacheTime;

        protected override void CreateChildControls() {
            this.Title = "Feed Properties";

            m_feedUrl = new TextBox() { ID = "feedUrl" };



            RegularExpressionValidator regValidator = new RegularExpressionValidator {
                ControlToValidate = m_feedUrl.ID,
                ValidationExpression = @"^(ht|f)tp(s?)\:\/\/[0-9a-zA-Z]([-.\w]*[0-9a-zA-Z])*(:(0-9)*)*(\/?)([a-zA-Z0-9\-\.\?\,\'\/\\\+&amp;%\$#_]*)?$",
                ErrorMessage = "Please provide a valud Url"
            };

            m_itemCount = new TextBox() { ID = "itemCount" };


            RangeValidator rv = new RangeValidator {
                ControlToValidate = m_itemCount.ID,
                MinimumValue = "1",
                MaximumValue = "100",
                Type = ValidationDataType.Integer,
                ErrorMessage = "Enter a value between 1 and 100"
            };



            m_cache = new CheckBox() { ID = "cache" };
            m_cache.CheckedChanged += new EventHandler(m_cache_CheckedChanged);
            m_cache.AutoPostBack = true;



            m_cacheTime = new TextBox() { ID = "cacheTime" };

            ToolPane pane = this.Zone as ToolPane;
            if (pane != null) {
                pane.Cancel.CausesValidation = false;
            }


            /*
             * 
              Panel genericPanel = new Panel() {CssClass = "UserGeneric"};
            this.Controls.Add(genericPanel);
            genericPanel.Controls.Add(new LiteralControl("RSS Web Part configuration<br/><br/>"));
            
            Panel headPanel = new Panel() {CssClass = "UserSectionHead ms-bold"};
            headPanel.Controls.Add(new LiteralControl("Feed Url"));
            genericPanel.Controls.Add(headPanel);
            Panel bodyPanel = new Panel(){CssClass = "UserSectionBody"};
            genericPanel.Controls.Add(bodyPanel);
            Panel groupPanel = new Panel(){CssClass = "UserControlGroup"};
            bodyPanel.Controls.Add(groupPanel);
            m_feedUrl.CssClass = "UserInput";
            m_feedUrl.Width = Unit.Pixel(176);
            groupPanel.Controls.Add(m_feedUrl);
            groupPanel.Controls.Add(new LiteralControl("<br/>"));
            regValidator.Display = ValidatorDisplay.Dynamic;
            groupPanel.Controls.Add(regValidator);

            headPanel = new Panel() { CssClass = "UserSectionHead ms-bold" };
            headPanel.Controls.Add(new LiteralControl("Items to show"));
            genericPanel.Controls.Add(headPanel);
            bodyPanel = new Panel() { CssClass = "UserSectionBody" };
            genericPanel.Controls.Add(bodyPanel);
            groupPanel = new Panel() { CssClass = "UserControlGroup" };
            bodyPanel.Controls.Add(groupPanel);
            m_itemCount.CssClass = "UserInput";
            m_itemCount.Style.Add("text-align", "right");
            m_itemCount.Columns = 10;
            groupPanel.Controls.Add(m_itemCount);
            groupPanel.Controls.Add(new LiteralControl("<br/>"));
            rangeValidator.Display = ValidatorDisplay.Dynamic;
            groupPanel.Controls.Add(rangeValidator);

            genericPanel.Controls.Add(new Panel() {CssClass = "UserDottedLine"});

            headPanel = new Panel() { CssClass = "UserSectionHead ms-bold" };
            headPanel.Controls.Add(new LiteralControl("Caching"));
            genericPanel.Controls.Add(headPanel);
            bodyPanel = new Panel() { CssClass = "UserSectionBody" };
            genericPanel.Controls.Add(bodyPanel);
            groupPanel = new Panel() { CssClass = "UserControlGroup" };
            bodyPanel.Controls.Add(groupPanel);
            m_cache.Text = "Enable caching";
            groupPanel.Controls.Add(m_cache);
            groupPanel.Controls.Add(new LiteralControl("<br/>Cache time:<br/>"));
            m_cacheTime.CssClass = "UserInput";
            m_cacheTime.Style.Add("text-align","right");
            m_cacheTime.Columns = 10;
            groupPanel.Controls.Add(m_cacheTime);
            


           
             */

            this.Controls.Add(new LiteralControl("Feed Url:<br/>"));
            this.Controls.Add(m_feedUrl);
            this.Controls.Add(regValidator);
            this.Controls.Add(new LiteralControl("<br/>Items to show:<br/>"));
            this.Controls.Add(m_itemCount);
            this.Controls.Add(rv);
            this.Controls.Add(new LiteralControl("<br/>Cache data:<br/>"));
            this.Controls.Add(m_cache);
            this.Controls.Add(new LiteralControl("<br/>Cache time:<br/>"));
            this.Controls.Add(m_cacheTime);

            base.CreateChildControls();
            this.ChildControlsCreated = true;
        }

        void m_cache_CheckedChanged(object sender, EventArgs e) {
            m_cacheTime.Enabled = m_cache.Checked;
        }

        public override bool ApplyChanges() {
            EnsureChildControls();
            AsyncRSSFeedWebPart webPart = this.WebPartToEdit as AsyncRSSFeedWebPart;
            if (webPart != null) {
                webPart.RssFeedUrl = m_feedUrl.Text;
                webPart.ItemCount = int.Parse(m_itemCount.Text);

                webPart.CacheData = m_cache.Checked;
                webPart.CacheTime = int.Parse(m_cacheTime.Text);
            }
            return true;
        }

        public override void SyncChanges() {
            EnsureChildControls();
            AsyncRSSFeedWebPart webPart = this.WebPartToEdit as AsyncRSSFeedWebPart;
            if (webPart != null) {
                m_feedUrl.Text = webPart.RssFeedUrl;
                m_itemCount.Text = webPart.ItemCount.ToString();


                m_cache.Checked = webPart.CacheData;
                m_cacheTime.Enabled = webPart.CacheData;
                m_cacheTime.Text = webPart.CacheTime.ToString();

            }

        }

    }
}
